document.addEventListener('DOMContentLoaded', () => {
  const startButton = document.getElementById('startRecording');
  const stopButton = document.getElementById('stopRecording');
  const transcriptionDiv = document.getElementById('transcription');
  const summaryDiv = document.getElementById('summary');

  let recognition = null;
  let isRecording = false;

  if ('webkitSpeechRecognition' in window) {
    recognition = new webkitSpeechRecognition();
    recognition.continuous = true;
    recognition.interimResults = true;

    recognition.onstart = () => {
      isRecording = true;
      startButton.disabled = true;
      stopButton.disabled = false;
      startButton.innerHTML = '<span class="icon">🎤</span> Recording...';
    };

    recognition.onend = () => {
      isRecording = false;
      startButton.disabled = false;
      stopButton.disabled = true;
      startButton.innerHTML = '<span class="icon">🎤</span> Start Recording';
      summarizeText();
    };

    recognition.onresult = (event) => {
      let interimTranscript = '';
      let finalTranscript = '';

      for (let i = event.resultIndex; i < event.results.length; i++) {
        const transcript = event.results[i][0].transcript;
        if (event.results[i].isFinal) {
          finalTranscript += transcript;
        } else {
          interimTranscript += transcript;
        }
      }

      transcriptionDiv.innerHTML = finalTranscript + 
        '<span style="color: gray;">' + interimTranscript + '</span>';
    };

    recognition.onerror = (event) => {
      console.error('Speech recognition error:', event.error);
      stopRecording();
    };
  }

  startButton.addEventListener('click', () => {
    if (recognition) {
      recognition.start();
    } else {
      alert('Speech recognition is not supported in your browser.');
    }
  });

  stopButton.addEventListener('click', stopRecording);

  function stopRecording() {
    if (recognition && isRecording) {
      recognition.stop();
    }
  }

  function summarizeText() {
    const text = transcriptionDiv.textContent;
    if (text.length < 50) {
      summaryDiv.textContent = text;
      return;
    }

    // Simple summarization algorithm
    const sentences = text.match(/[^.!?]+[.!?]+/g) || [];
    const summary = sentences
      .slice(0, Math.min(3, sentences.length))
      .join(' ');
    
    summaryDiv.textContent = summary;
  }
});
